# python-self-use

#### 介绍

#### 软件架构
软件架构说明


#### 安装教程

https://pypi.org/project/python-self-use/0.0.1/

1.  pip install onepx

#### 使用说明

"""
import onepx

ocrtext2df(text, 3)

"""

#### 参与贡献

1.  Fork 本仓库
2.  新建 Feat_xxx 分支
3.  提交代码
4.  新建 Pull Request



